
-- return the window size
function getWindowSize()
	return 520, 256
end

-- return the main font
-- the return is a list of font filename and size options
-- the first one found will be used
function getFont()
	if isMac then
		return { { name="GillSans.ttc", size=14 }, { name="GillSans.dfont", size=14 }, { name="Monaco.dfont", size=12 } }
	else
		return { { name="tahoma.ttf", size=14 }, { name="arial.ttf", size=12 } }
	end
end
-- return the label font
function getLabelFont()
	if isMac then
		return { { name="GillSans.ttc", size=11 }, { name="GillSans.dfont", size=11 }, { name="Monaco.dfont", size=9 } }
	else
		return { { name="tahoma.ttf", size=11 }, { name="arial.ttf", size=9 } }
	end
end
-- return the text field font
function getTextFieldFont()
	if isMac then
		return { { name="GillSans.ttc", size=12 }, { name="GillSans.dfont", size=12 }, { name="Monaco.dfont", size=10 } }
	else
		return { { name="tahoma.ttf", size=12 }, { name="arial.ttf", size=10 } }
	end
end

-- create and lay out all the controls
function createUI()

	-- constants
	local kKnobSize = 35
	local kKnobSpace = 50
	local kTextFieldH = 12
	local pad = 10.0
	local ww, wh = getWindowSize()

	-- set window background colour
	setBackgroundColour( 0.5, 0.1, 0.1 )

	-- set location of the banner
	setBannerPosition( wh - 20 )

	-- set outline colours for groups
	setGroupActiveColour( 0.5, 0.6, 0.7, 0.6 )
	setGroupInactiveColour( 0.4, 0.4, 0.6, 0.5 )
	
	local function knobAndTextField( group, param, label, x, y )
		local size = kKnobSize
		local knobx = x + 0.5 * ( kKnobSize - size )
		group:add( knob( param, "", knobx, y+kTextFieldH+1, size ) )
		group:add( textField( param, label, x, y, kKnobSize, kTextFieldH, "below" ) )
	end

	-- make groups and knobs
	--

	mixGroup = group( "Mix" )
	knobAndTextField( mixGroup,	"Dry Level", 	"Dry", 0*kKnobSpace, 0 )
	knobAndTextField( mixGroup, "Effect Level", "Wet", 1*kKnobSpace, 0 )

	speedGroup = group( "Speed" )
	knobAndTextField( speedGroup, "Speed (superfine)", 	"Superfine", 	0*kKnobSpace, 0 )
	knobAndTextField( speedGroup, "Speed (fine)", 		"Fine", 		1*kKnobSpace, 0 )
	knobAndTextField( speedGroup, "Speed (coarse)", 	"Coarse", 		2*kKnobSpace, 0 )

	depthGroup = group( "Depth" )
	knobAndTextField( depthGroup, "Depth (fine)", 	"Fine", 	0*kKnobSpace, 0 )
	knobAndTextField( depthGroup, "Depth (coarse)", "Coarse", 	1*kKnobSpace, 0 )

	shapeGroup = group( "Shape" )
	knobAndTextField( shapeGroup, "Shape", 	"Shape", 	0*kKnobSpace, 0 )
	knobAndTextField( shapeGroup, "Spread", "Spread", 	1*kKnobSpace, 0 )

	chorusGroup = group( "Chorus/Flange" )
	knobAndTextField( chorusGroup, "Bias", 		"Bias", 	0*kKnobSpace, 0 )
	knobAndTextField( chorusGroup, "Feedback", 	"Feedback", 1*kKnobSpace, 0 )

	speedLfoGroup = group( "Speed LFO" )
	knobAndTextField( speedLfoGroup, "Speed LFO Speed", "Speed", 0*kKnobSpace, 0 )
	knobAndTextField( speedLfoGroup, "Speed LFO Depth", "Depth", 1*kKnobSpace, 0 )

	depthLfoGroup = group( "Depth LFO" )
	knobAndTextField( depthLfoGroup, "Depth LFO Speed", "Speed", 0*kKnobSpace, 0 )
	knobAndTextField( depthLfoGroup, "Depth LFO Depth", "Depth", 1*kKnobSpace, 0 )

	oscGroup = group( "OSC" )
	knobAndTextField( oscGroup, "OSC Port Offset", "Port", 0*kKnobSpace, 0 )

	-- positions!

	xbase = 20
	ybase = 20+10

	xbase1 = xbase 	+ speedGroup:width() 		+ pad
	xbase2 = xbase1 + mixGroup:width() 			+ pad
	xbase3 = xbase2 + chorusGroup:width() 		+ pad
	ybase1 = ybase 	+ speedLfoGroup:height()	+ pad
	ybase2 = ybase1 + speedGroup:height() 		+ pad

	speedLfoGroup:setPosition( xbase, ybase )
	speedGroup:setPosition( xbase, ybase1 )
	depthLfoGroup:setPosition( xbase1, ybase )
	depthGroup:setPosition( xbase1, ybase1 )
	chorusGroup:setPosition( xbase2, ybase )
	shapeGroup:setPosition( xbase2, ybase1 )
	mixGroup:setPosition( xbase3, ybase1 )
	oscGroup:setPosition( xbase3, ybase )

	-- add directly positioned objects
	--

	x = xbase3
	y = ybase2 - 10

	-- add the prefs button
	add( button( "Prefs", "Prefs", x, y, 90, 30 ) )

	-- add the info display object
	x = xbase
	y = y + 10
	add( infoDisplay( x, y, 100, 40 ) )

end		-- of createUI()
